%% script for benchmarking film processing

clear
close all
clc

timerPeriod = 0.05; % in seconds
% create timer object
hTimer = timer('BusyMode', 'queue', 'ExecutionMode', 'fixedSpacing', ...
   'Period', timerPeriod);

% set callbacks to timer object
hTimer.TimerFcn = @(hTimer, ~)continuosCheckMemory(hTimer);
hTimer.StartFcn = @(hTimer, ~)startCheckMemory(hTimer);

%% set input arguments to your function here
videoFilePath = '';
startTime = 0;
endTime = 0;
crop = [40, 300, 1350, 980];
outputFolderPath = 'videoFrames';
height = 480;

%% For time measurement you code runs for nRuns and results are averaged.
nRuns = 3;
%% starting benchmarking
start(hTimer);
tic
for iRun = 1:nRuns
   %% call here your function
   
   analogFilmProcessYourlogin(videoFilePath, startTime, endTime, crop, ...
      outputFolderPath, height);
   
end
%% analyze benchmark and show results
stop(hTimer);
timeOfProcessing = toc/nRuns; % average of measured time
% show processing time
fprintf('Time of video processing was %0.5f s\n', timeOfProcessing);
% number of exported images
nOfExportedFrames = length(dir(outputFolderPath))-2;
timePerFrame = timeOfProcessing/nOfExportedFrames;
fprintf('Time of video processing per one frame was %0.5f s/frame \n', timePerFrame);
% compute memory used by Matlab
userData = hTimer.UserData;
usedMemory = (userData.memAvailableAtStart - ...
   userData.progressOfAvailableMemory)/1024/1024; % in MB
delete(hTimer);
nMeasurements = size(usedMemory, 1);
% time axis
tAxis = linspace(0, timeOfProcessing, nMeasurements);

% create figure with memory consumptions
hFig = figure;
hAx = axes('Parent', hFig, 'XGrid', 'on', 'YGrid', 'on');
hAx.XLabel.String = 'time (s)';
hAx.YLabel.String = 'RAM memory used by Matlab (MB)';

hLine = line('Parent', hAx, 'LineWidth', 2, 'XData', tAxis, ...
   'YData', usedMemory, 'Color', 'g', 'Marker', '*');
hLineLimit = line('Parent', hAx, 'LineWidth', 2, ...
   'XData', [tAxis(1), tAxis(end)], 'YData', [1024 1024], 'Color', 'r');